"""Find the Xenoi (external account trusts) in your AWS Account."""
from pathlib import Path
from awsxenos.finding import AccountType, Finding

package_path = Path(__file__)
